==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.md <==
# ServiceAzureLighthouse


```text
azure-4/Item/ManagementGovernance/ServiceAzureLighthouse
```

```text
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')
```



| Illustration | ServiceAzureLighthouse | ServiceAzureLighthouseCard | ServiceAzureLighthouseGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.png) | ![illustration for ServiceAzureLighthouse](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.Local.png) | ![illustration for ServiceAzureLighthouseCard](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouseCard.Local.png) | ![illustration for ServiceAzureLighthouseGroup](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouseGroup.Local.png) |




## ServiceAzureLighthouse

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouse
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouse('ServiceAzureLighthouse', 'Service Azure Lighthouse', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouse
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouse('ServiceAzureLighthouse', 'Service Azure Lighthouse', 'an optional tech label')
@enduml
```

## ServiceAzureLighthouseCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseCard
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseCard('ServiceAzureLighthouseCard', 'Service Azure Lighthouse Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseCard
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseCard('ServiceAzureLighthouseCard', 'Service Azure Lighthouse Card', 'an optional description')
@enduml
```

## ServiceAzureLighthouseGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseGroup
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseGroup('ServiceAzureLighthouseGroup', 'Service Azure Lighthouse Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseGroup
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseGroup('ServiceAzureLighthouseGroup', 'Service Azure Lighthouse Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.md <==
# ServiceAzureLighthouse


```text
azure-4/Item/ManagementGovernance/ServiceAzureLighthouse
```

```text
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')
```



| Illustration | ServiceAzureLighthouse | ServiceAzureLighthouseCard | ServiceAzureLighthouseGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.png) | ![illustration for ServiceAzureLighthouse](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouse.Local.png) | ![illustration for ServiceAzureLighthouseCard](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouseCard.Local.png) | ![illustration for ServiceAzureLighthouseGroup](../../../azure-4/Item/ManagementGovernance/ServiceAzureLighthouseGroup.Local.png) |




## ServiceAzureLighthouse

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouse
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouse('ServiceAzureLighthouse', 'Service Azure Lighthouse', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouse
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouse('ServiceAzureLighthouse', 'Service Azure Lighthouse', 'an optional tech label')
@enduml
```

## ServiceAzureLighthouseCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseCard
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseCard('ServiceAzureLighthouseCard', 'Service Azure Lighthouse Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseCard
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseCard('ServiceAzureLighthouseCard', 'Service Azure Lighthouse Card', 'an optional description')
@enduml
```

## ServiceAzureLighthouseGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseGroup
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseGroup('ServiceAzureLighthouseGroup', 'Service Azure Lighthouse Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAzureLighthouseGroup
include('azure-4/Item/ManagementGovernance/ServiceAzureLighthouse')

' renders the element
ServiceAzureLighthouseGroup('ServiceAzureLighthouseGroup', 'Service Azure Lighthouse Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
